chldidel_next
Details
Question What do you think is the ideal number of children for a family to have? NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT
Values
[7]7 or more[8]as many as you want[NA(d)]don't know[NA(i)]iap[NA(j)]I don't have a job[NA(m)]dk, na, iap[NA(n)]no answer[NA(p)]not imputable[NA(r)]refused[NA(s)]skipped on web[NA(u)]uncodeable[NA(x)]not available in this release[NA(y)]not available in this year[NA(z)]see codebook
Overview
For further details see the GSS Data Explorer page for chldidel_next.
Counts by year:
| year | not available in this year | 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 or more | as many as you want | iap | skipped on web | Total |
| 2024 | - | 9 | 32 | 441 | 188 | 67 | 12 | 5 | 6 | 303 | 2244 | 2 | 3309 |
| Total | 0 | 9 | 32 | 441 | 188 | 67 | 12 | 5 | 6 | 303 | 2244 | 2 | 3309 |
See also
Other GSS Next:
chldpref_next,
happy_next,
knwsexor,
perla_self,
topprob1_next,
topprob2_crim,
topprob2_educ,
topprob2_envr,
topprob2_hlth
Other Children:
chldpref_next