chldpref_next
Details
Question For you personally, what is the ideal number of children you would like to have or would have liked to have had? NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT
Values
[7]7 or more[8]as many as you want[NA(d)]don't know[NA(i)]iap[NA(j)]I don't have a job[NA(m)]dk, na, iap[NA(n)]no answer[NA(p)]not imputable[NA(r)]refused[NA(s)]skipped on web[NA(u)]uncodeable[NA(x)]not available in this release[NA(y)]not available in this year[NA(z)]see codebook
Overview
For further details see the GSS Data Explorer page for chldpref_next.
Counts by year:
| year | not available in this year | 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 or more | as many as you want | iap | skipped on web | Total |
| 2024 | - | 127 | 85 | 432 | 203 | 100 | 31 | 15 | 12 | 58 | 2244 | 2 | 3309 |
| Total | 0 | 127 | 85 | 432 | 203 | 100 | 31 | 15 | 12 | 58 | 2244 | 2 | 3309 |
See also
Other GSS Next:
chldidel_next,
happy_next,
knwsexor,
perla_self,
topprob1_next,
topprob2_crim,
topprob2_educ,
topprob2_envr,
topprob2_hlth
Other Children:
chldidel_next