Skip to contents

credam

General Social Survey https://gss.norc.org

Details

Question Now, thinking about Americans in general, do you think credit scores are more the result of choices people make or things out of their control? NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT

Values

  • [1] entirely choices they make

  • [2] mostly choices they make

  • [3] both choices they make and things out of their control

  • [4] mostly things out of their control

  • [5] entirely things out of their control

  • [NA(d)] can't choose [NA(i)] iap [NA(j)] I don't have a job [NA(m)] dk, na, iap [NA(n)] no answer [NA(p)] not imputable [NA(r)] refused [NA(s)] skipped on web [NA(u)] uncodeable [NA(x)] not available in this release [NA(y)] not available in this year [NA(z)] see codebook

Question Years and Ballots

ballotsyears
A/B/C2024

Overview

For further details see the GSS Data Explorer page for credam.

Counts by year:

yearnot available in this yearentirely choices they makemostly choices they makeboth choices they make and things out of their controlmostly things out of their controlentirely things out of their controliapskipped on webTotal
2024-143360505514224423309
Total0143360505514224423309

See also