R's credit score has to do with choices or things out of your control
Source:R/gss_vars_688.R
credchoice.Rdcredchoice
Details
Question Would you say your current credit score has more to do with choices you’ve made or things out of your control? NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT
Values
[1]entirely choices you've made[2]mostly choices you've made[3]both choices you've made and things out of your control[4]mostly things out of your control[5]entirely things out of your control[NA(d)]can't choose[NA(i)]iap[NA(j)]I don't have a job[NA(m)]dk, na, iap[NA(n)]no answer[NA(p)]not imputable[NA(r)]refused[NA(s)]skipped on web[NA(u)]uncodeable[NA(x)]not available in this release[NA(y)]not available in this year[NA(z)]see codebook
Overview
For further details see the GSS Data Explorer page for credchoice.
Counts by year:
| year | not available in this year | entirely choices you've made | mostly choices you've made | both choices you've made and things out of your control | mostly things out of your control | entirely things out of your control | iap | skipped on web | Total |
| 2024 | - | 352 | 331 | 304 | 57 | 20 | 2244 | 1 | 3309 |
| Total | 0 | 352 | 331 | 304 | 57 | 20 | 2244 | 1 | 3309 |