Skip to contents

credland

General Social Survey https://gss.norc.org

Details

Question (It’s not only lenders that use credit reports to make decisions. How fair or unfair do you think it is for each of the following to use credit reports?) Landlords deciding who to rent to. NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT

Values

  • [1] very fair

  • [2] somewhat fair

  • [3] neither fair nor unfair

  • [4] somewhat unfair

  • [5] very unfair

  • [NA(d)] can't choose [NA(i)] iap [NA(j)] I don't have a job [NA(m)] dk, na, iap [NA(n)] no answer [NA(p)] not imputable [NA(r)] refused [NA(s)] skipped on web [NA(u)] uncodeable [NA(x)] not available in this release [NA(y)] not available in this year [NA(z)] see codebook

Question Years and Ballots

ballotsyears
A/B/C2024

Overview

For further details see the GSS Data Explorer page for credland.

Counts by year:

yearnot available in this yearvery fairsomewhat fairneither fair nor unfairsomewhat unfairvery unfairiapskipped on webTotal
2024-26337714719582224413309
Total026337714719582224413309

See also