Number of family generations in household - follow-on version
Source:R/gss_vars_690.R
famgen_next.Rdfamgen_next
Details
Question Given what you said, how many family generations live in this household? NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT
Values
[1]one generation[2]two generations, children[3]two generations, parents[4]two generations, grandchild(ren)[5]three or more generations[NA(d)]don't know[NA(i)]iap[NA(j)]I don't have a job[NA(m)]dk, na, iap[NA(n)]no answer[NA(p)]not imputable[NA(r)]refused[NA(s)]skipped on web[NA(u)]uncodeable[NA(x)]not available in this release[NA(y)]not available in this year[NA(z)]see codebook
Overview
For further details see the GSS Data Explorer page for famgen_next.
Counts by year:
| year | not available in this year | one generation | two generations, children | two generations, parents | two generations, grandchild(ren) | three or more generations | iap | skipped on web | Total |
| 2024 | - | 670 | 235 | 68 | 11 | 31 | 2268 | 26 | 3309 |
| Total | 0 | 670 | 235 | 68 | 11 | 31 | 2268 | 26 | 3309 |
See also
Other GSS Next:
hhtype1_next,
topprob2_econ,
topprob2_immg,
topprob2_none,
topprob2_povt,
topprob2_terr
Other GSS Next:
hhtype1_next,
topprob2_econ,
topprob2_immg,
topprob2_none,
topprob2_povt,
topprob2_terr