happy_next
Details
Question Taken all together, how would you say things are these days—would you say that you are very happy, pretty happy, or not too happy? NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT
Values
[1]very happy[2]pretty happy[3]not too happy[NA(d)]don't know[NA(i)]iap[NA(j)]I don't have a job[NA(m)]dk, na, iap[NA(n)]no answer[NA(p)]not imputable[NA(r)]refused[NA(s)]skipped on web[NA(u)]uncodeable[NA(x)]not available in this release[NA(y)]not available in this year[NA(z)]see codebook
Overview
For further details see the GSS Data Explorer page for happy_next.
Counts by year:
| year | not available in this year | very happy | pretty happy | not too happy | iap | skipped on web | Total |
| 2024 | - | 160 | 622 | 280 | 2244 | 3 | 3309 |
| Total | 0 | 160 | 622 | 280 | 2244 | 3 | 3309 |
See also
Other GSS Next:
chldidel_next,
chldpref_next,
knwsexor,
perla_self,
topprob1_next,
topprob2_crim,
topprob2_educ,
topprob2_envr,
topprob2_hlth
Other GSS Next:
chldidel_next,
chldpref_next,
knwsexor,
perla_self,
topprob1_next,
topprob2_crim,
topprob2_educ,
topprob2_envr,
topprob2_hlth