knwsexor
Details
Question Among your immediate family members, relatives, neighbors, co-workers, or close friends, are any of them gay, lesbian, or bisexual as far as you know? NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT
Values
[1]yes[2]no[NA(d)]don't know[NA(i)]iap[NA(j)]I don't have a job[NA(m)]dk, na, iap[NA(n)]no answer[NA(p)]not imputable[NA(r)]refused[NA(s)]skipped on web[NA(u)]uncodeable[NA(x)]not available in this release[NA(y)]not available in this year[NA(z)]see codebook
Overview
For further details see the GSS Data Explorer page for knwsexor.
Counts by year:
| year | not available in this year | yes | no | iap | skipped on web | Total |
| 2024 | - | 721 | 340 | 2244 | 4 | 3309 |
| Total | 0 | 721 | 340 | 2244 | 4 | 3309 |
See also
Other GSS Next:
chldidel_next,
chldpref_next,
happy_next,
perla_self,
topprob1_next,
topprob2_crim,
topprob2_educ,
topprob2_envr,
topprob2_hlth
Other GSS Next:
chldidel_next,
chldpref_next,
happy_next,
perla_self,
topprob1_next,
topprob2_crim,
topprob2_educ,
topprob2_envr,
topprob2_hlth