Skip to contents

perla_self

General Social Survey https://gss.norc.org

Details

Question Using the skin tone palette below, please select the option that most matches your skin tone. NOTE: Please see the 2024 Codebook for more information on this variable. This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT

Values

  • [1] 1 - lightest

  • [12] 12 - darkest

  • [NA(d)] don't know [NA(i)] iap [NA(j)] I don't have a job [NA(m)] dk, na, iap [NA(n)] no answer [NA(p)] not imputable [NA(r)] refused [NA(s)] skipped on web [NA(u)] uncodeable [NA(x)] not available in this release [NA(y)] not available in this year [NA(z)] see codebook

Question Years and Ballots

ballotsyears
A/B/C2024

Overview

For further details see the GSS Data Explorer page for perla_self.

Counts by year:

yearnot available in this year1 - lightest101112 - darkest23456789don't knowiapskipped on webTotal
2024-186135118289310985047152042224563309
Total0186135118289310985047152042224563309