Skip to contents

topprob2_hlth

General Social Survey https://gss.norc.org

Details

Question Do any other issues match your answer to the previous question (TOPPROB1_NEXT)? Health care NOTE: This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT

Values

  • [1] mentioned

  • [2] not mentioned

  • [NA(d)] don't know [NA(i)] iap [NA(j)] I don't have a job [NA(m)] dk, na, iap [NA(n)] no answer [NA(p)] not imputable [NA(r)] refused [NA(s)] skipped on web [NA(u)] uncodeable [NA(x)] not available in this release [NA(y)] not available in this year [NA(z)] see codebook

Question Years and Ballots

ballotsyears
A/B/C2024

Overview

For further details see the GSS Data Explorer page for topprob2_hlth.

Counts by year:

yearnot available in this yearmentionednot mentionediapskipped on webTotal
2024-23258322612333309
Total023258322612333309