Skip to contents

wordsumnew

General Social Survey https://gss.norc.org

Details

Question We would like to know something about how people go about guessing words they do not know. On this card are listed some words–you may know some of them, and you may not know quite a few of them. On each line the first word is in capital letters – like BEAST. Then there are five other words. Tell me the number of the word that comes closest to the meaning of the word in capital letters. For example, if the word in capital letters is BEAST, you would say "4" since "animal" come closer to BEAST than any of the other words. If you wish, I will read the words to you. These words are difficult for almost everyone – just give me your best guess if you are not sure of the answer. CIRCLE ONE CODE NUMBER FOR EACH ITEM BELOW.

K. Total number of correct words. NOTE: This variable contains the 10 experimental vocabulary items from WORDSUM. For more details, see the Codebook. For more details, see the Codebook.

Values

  • [NA(d)] don't know [NA(i)] iap [NA(j)] I don't have a job [NA(m)] dk, na, iap [NA(n)] no answer [NA(p)] not imputable [NA(r)] refused [NA(s)] skipped on web [NA(u)] uncodeable [NA(x)] not available in this release [NA(y)] not available in this year [NA(z)] see codebook

Question Years and Ballots

ballotsyears
A/B/-2022
A/B/C2024

Overview

For further details see the GSS Data Explorer page for wordsumnew.

Counts by year:

yearnot available in this year011023456789iapno answerTotal
2022-6279434651021521681561911702339403544
2024-6316630748213616215817617516265873309
Total012581606413918428833031436734539656276853