perla_self
Details
Question Using the skin tone palette below, please select the option that most matches your skin tone. NOTE: Please see the 2024 Codebook for more information on this variable. This variable originates on the GSS Next follow-on, and should not be analyzed without the GSS Next-specific weights WTSSPS_NEXT or WTSSNRPS_NEXT
Values
[1]1 - lightest[12]12 - darkest[NA(d)]don't know[NA(i)]iap[NA(j)]I don't have a job[NA(m)]dk, na, iap[NA(n)]no answer[NA(p)]not imputable[NA(r)]refused[NA(s)]skipped on web[NA(u)]uncodeable[NA(x)]not available in this release[NA(y)]not available in this year[NA(z)]see codebook
Overview
For further details see the GSS Data Explorer page for perla_self.
Counts by year:
| year | not available in this year | 1 - lightest | 10 | 11 | 12 - darkest | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | don't know | iap | skipped on web | Total |
| 2024 | - | 186 | 13 | 5 | 1 | 182 | 89 | 310 | 98 | 50 | 47 | 15 | 20 | 42 | 2245 | 6 | 3309 |
| Total | 0 | 186 | 13 | 5 | 1 | 182 | 89 | 310 | 98 | 50 | 47 | 15 | 20 | 42 | 2245 | 6 | 3309 |
See also
Other GSS Next:
chldidel_next,
chldpref_next,
happy_next,
knwsexor,
topprob1_next,
topprob2_crim,
topprob2_educ,
topprob2_envr,
topprob2_hlth